Glyph Name Information — jkUnicode 1.6.1 documentation

# Glyph Name Information

The information in this module is autogenerated by the script tools/generatePyUniData.py. Edit the source data and regenerate the module if you need to change anything.

`jkUnicode.aglfn.` `getGlyphnameForUnicode`(code)

  Return the name as string or None that is assigned to the specified Unicode value.

  Parameters

    code (int) – The codepoint.

`jkUnicode.aglfn.` `getUnicodeForGlyphname`(name)

  Return the Unicode value as integer or None that is assigned to the specified glyph name. It handles AGLFN names, uniXXXX names, uXXXXX names, ligature names, variant names, and PUA-encoded ornament names (orn001 - orn999, starting at 0xEA01).

  Parameters

    name (str) – The glyph name.